#
# spec file for package ghc-attoparsec
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name attoparsec
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.13.1.0
Release:        3.1
Summary:        Fast combinator parsing for bytestrings and text
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-quickcheck-unicode-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-vector-devel
%endif

%description
A fast parser combinator library, aimed particularly at dealing efficiently
with network protocols and complicated text/binary file formats.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.markdown changelog.md examples

%changelog
* Mon Sep 26 2016 psimons@suse.com
- Update to version 0.13.1.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.13.0.2 revision 0 with cabal2obs.
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 0.13.0.2
- remove useless _service
  * Restore the fast specialised character set implementation for Text
  * Move testsuite from test-framework to tasty
  * Performance optimization of takeWhile and takeWhile1
* Mon Sep 28 2015 mimi.vx@gmail.com
- update to 0.13.0.1
  * Fixed a bug in the implementations of inClass and notInClass for Text
  * Made the parser type in the Zepto module a monad transformer.
* Mon Apr 13 2015 mimi.vx@gmail.com
- update to 0.12.1.6
  * Fixed a case folding bug in the ByteString version of stringCI.
  * Fixed an indexing bug in the new Text implementation of string,
  reported by Michel Boucey.
  * Fixed a case where the string parser would consume an unnecessary
  amount of input before failing a match, when it could bail much
  earlier (https://github.com/bos/attoparsec/issues/97)
  * Added more context to error messages
  (https://github.com/bos/attoparsec/pull/79)
  * Fixed incorrect tracking of Text lengths
  (https://github.com/bos/attoparsec/issues/80)
  * Fixed the incorrect tracking of capacity if the initial buffer was
  empty (https://github.com/bos/attoparsec/issues/75)
  * Fixed a data corruption bug that occurred under some circumstances
  if a buffer grew after prompting for more input
  (https://github.com/bos/attoparsec/issues/74)
  * Now compatible with GHC 7.9
  * Reintroduced the Chunk class, used by the parsers package
  * A new internal representation makes almost all real-world parsers
  faster, sometimes by big margins.  For example, parsing JSON data
  with aeson is now up to 70%% faster.  These performance improvements
  also come with reduced memory consumption and some new capabilities.
  * The new match combinator gives both the result of a parse and the
  input that it matched.
  * The test suite has doubled in size.  This made it possible to switch
  to the new internal representation with a decent degree of
  confidence that everything was more or less working.
  * The benchmark suite now contains a small family of benchmarks taken
  from real-world uses of attoparsec.
  * A few types that ought to have been private now are.
  * A few obsolete modules and functions have been marked as deprecated.
  They will be removed from the next major release.
  * New function scientific is compatible with rational, but parses
  integers more efficiently (https://github.com/bos/aeson/issues/198)
  * The new Chunk typeclass allows for some code sharing with Ed
  Kmett's parsers package: http://hackage.haskell.org/package/parsers
  * New function runScanner generalises scan to return the final state
  of the scanner as well as the input consumed.
  * New dependency: the scientific package.  This allows us to parse
  numbers much more efficiently.
  * peekWord8', peekChar': new primitive parsers that allow
  single-character lookahead.
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May 21 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Mon Feb  4 2013 peter.trommler@ohm-hochschule.de
- update to 0.10.4.0 from upstream (no changelog)
- fixes bugs and performance issues
- currently under consideration for inclusion in Haskell Platform
* Sat Jun  9 2012 peter.trommler@ohm-hochschule.de
- package LICENSE file
- add copyright notice
* Fri Mar  2 2012 peter.trommler@ohm-hochschule.de
- initial packaging
